# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from opentelemetry.proto.common.v1.common_pb2 import (
    AnyValue as opentelemetry___proto___common___v1___common_pb2___AnyValue,
    InstrumentationLibrary as opentelemetry___proto___common___v1___common_pb2___InstrumentationLibrary,
    KeyValue as opentelemetry___proto___common___v1___common_pb2___KeyValue,
)

from opentelemetry.proto.resource.v1.resource_pb2 import (
    Resource as opentelemetry___proto___resource___v1___resource_pb2___Resource,
)

from typing import (
    Iterable as typing___Iterable,
    List as typing___List,
    NewType as typing___NewType,
    Optional as typing___Optional,
    Text as typing___Text,
    Tuple as typing___Tuple,
    Union as typing___Union,
    cast as typing___cast,
)

from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
builtin___str = str
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

SeverityNumberValue = typing___NewType("SeverityNumberValue", builtin___int)
type___SeverityNumberValue = SeverityNumberValue

class SeverityNumber(object):
    DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
    @classmethod
    def Name(cls, number: builtin___int) -> builtin___str: ...
    @classmethod
    def Value(cls, name: builtin___str) -> SeverityNumberValue: ...
    @classmethod
    def keys(cls) -> typing___List[builtin___str]: ...
    @classmethod
    def values(cls) -> typing___List[SeverityNumberValue]: ...
    @classmethod
    def items(
        cls,
    ) -> typing___List[typing___Tuple[builtin___str, SeverityNumberValue]]: ...
    SEVERITY_NUMBER_UNSPECIFIED = typing___cast(SeverityNumberValue, 0)
    SEVERITY_NUMBER_TRACE = typing___cast(SeverityNumberValue, 1)
    SEVERITY_NUMBER_TRACE2 = typing___cast(SeverityNumberValue, 2)
    SEVERITY_NUMBER_TRACE3 = typing___cast(SeverityNumberValue, 3)
    SEVERITY_NUMBER_TRACE4 = typing___cast(SeverityNumberValue, 4)
    SEVERITY_NUMBER_DEBUG = typing___cast(SeverityNumberValue, 5)
    SEVERITY_NUMBER_DEBUG2 = typing___cast(SeverityNumberValue, 6)
    SEVERITY_NUMBER_DEBUG3 = typing___cast(SeverityNumberValue, 7)
    SEVERITY_NUMBER_DEBUG4 = typing___cast(SeverityNumberValue, 8)
    SEVERITY_NUMBER_INFO = typing___cast(SeverityNumberValue, 9)
    SEVERITY_NUMBER_INFO2 = typing___cast(SeverityNumberValue, 10)
    SEVERITY_NUMBER_INFO3 = typing___cast(SeverityNumberValue, 11)
    SEVERITY_NUMBER_INFO4 = typing___cast(SeverityNumberValue, 12)
    SEVERITY_NUMBER_WARN = typing___cast(SeverityNumberValue, 13)
    SEVERITY_NUMBER_WARN2 = typing___cast(SeverityNumberValue, 14)
    SEVERITY_NUMBER_WARN3 = typing___cast(SeverityNumberValue, 15)
    SEVERITY_NUMBER_WARN4 = typing___cast(SeverityNumberValue, 16)
    SEVERITY_NUMBER_ERROR = typing___cast(SeverityNumberValue, 17)
    SEVERITY_NUMBER_ERROR2 = typing___cast(SeverityNumberValue, 18)
    SEVERITY_NUMBER_ERROR3 = typing___cast(SeverityNumberValue, 19)
    SEVERITY_NUMBER_ERROR4 = typing___cast(SeverityNumberValue, 20)
    SEVERITY_NUMBER_FATAL = typing___cast(SeverityNumberValue, 21)
    SEVERITY_NUMBER_FATAL2 = typing___cast(SeverityNumberValue, 22)
    SEVERITY_NUMBER_FATAL3 = typing___cast(SeverityNumberValue, 23)
    SEVERITY_NUMBER_FATAL4 = typing___cast(SeverityNumberValue, 24)

SEVERITY_NUMBER_UNSPECIFIED = typing___cast(SeverityNumberValue, 0)
SEVERITY_NUMBER_TRACE = typing___cast(SeverityNumberValue, 1)
SEVERITY_NUMBER_TRACE2 = typing___cast(SeverityNumberValue, 2)
SEVERITY_NUMBER_TRACE3 = typing___cast(SeverityNumberValue, 3)
SEVERITY_NUMBER_TRACE4 = typing___cast(SeverityNumberValue, 4)
SEVERITY_NUMBER_DEBUG = typing___cast(SeverityNumberValue, 5)
SEVERITY_NUMBER_DEBUG2 = typing___cast(SeverityNumberValue, 6)
SEVERITY_NUMBER_DEBUG3 = typing___cast(SeverityNumberValue, 7)
SEVERITY_NUMBER_DEBUG4 = typing___cast(SeverityNumberValue, 8)
SEVERITY_NUMBER_INFO = typing___cast(SeverityNumberValue, 9)
SEVERITY_NUMBER_INFO2 = typing___cast(SeverityNumberValue, 10)
SEVERITY_NUMBER_INFO3 = typing___cast(SeverityNumberValue, 11)
SEVERITY_NUMBER_INFO4 = typing___cast(SeverityNumberValue, 12)
SEVERITY_NUMBER_WARN = typing___cast(SeverityNumberValue, 13)
SEVERITY_NUMBER_WARN2 = typing___cast(SeverityNumberValue, 14)
SEVERITY_NUMBER_WARN3 = typing___cast(SeverityNumberValue, 15)
SEVERITY_NUMBER_WARN4 = typing___cast(SeverityNumberValue, 16)
SEVERITY_NUMBER_ERROR = typing___cast(SeverityNumberValue, 17)
SEVERITY_NUMBER_ERROR2 = typing___cast(SeverityNumberValue, 18)
SEVERITY_NUMBER_ERROR3 = typing___cast(SeverityNumberValue, 19)
SEVERITY_NUMBER_ERROR4 = typing___cast(SeverityNumberValue, 20)
SEVERITY_NUMBER_FATAL = typing___cast(SeverityNumberValue, 21)
SEVERITY_NUMBER_FATAL2 = typing___cast(SeverityNumberValue, 22)
SEVERITY_NUMBER_FATAL3 = typing___cast(SeverityNumberValue, 23)
SEVERITY_NUMBER_FATAL4 = typing___cast(SeverityNumberValue, 24)
type___SeverityNumber = SeverityNumber

LogRecordFlagsValue = typing___NewType("LogRecordFlagsValue", builtin___int)
type___LogRecordFlagsValue = LogRecordFlagsValue

class LogRecordFlags(object):
    DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
    @classmethod
    def Name(cls, number: builtin___int) -> builtin___str: ...
    @classmethod
    def Value(cls, name: builtin___str) -> LogRecordFlagsValue: ...
    @classmethod
    def keys(cls) -> typing___List[builtin___str]: ...
    @classmethod
    def values(cls) -> typing___List[LogRecordFlagsValue]: ...
    @classmethod
    def items(
        cls,
    ) -> typing___List[typing___Tuple[builtin___str, LogRecordFlagsValue]]: ...
    LOG_RECORD_FLAG_UNSPECIFIED = typing___cast(LogRecordFlagsValue, 0)
    LOG_RECORD_FLAG_TRACE_FLAGS_MASK = typing___cast(LogRecordFlagsValue, 255)

LOG_RECORD_FLAG_UNSPECIFIED = typing___cast(LogRecordFlagsValue, 0)
LOG_RECORD_FLAG_TRACE_FLAGS_MASK = typing___cast(LogRecordFlagsValue, 255)
type___LogRecordFlags = LogRecordFlags

class ResourceLogs(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def resource(
        self,
    ) -> opentelemetry___proto___resource___v1___resource_pb2___Resource: ...
    @property
    def instrumentation_library_logs(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___InstrumentationLibraryLogs
    ]: ...
    def __init__(
        self,
        *,
        resource: typing___Optional[
            opentelemetry___proto___resource___v1___resource_pb2___Resource
        ] = None,
        instrumentation_library_logs: typing___Optional[
            typing___Iterable[type___InstrumentationLibraryLogs]
        ] = None,
    ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> ResourceLogs: ...
    else:
        @classmethod
        def FromString(
            cls,
            s: typing___Union[
                builtin___bytes, builtin___buffer, builtin___unicode
            ],
        ) -> ResourceLogs: ...
    def HasField(
        self, field_name: typing_extensions___Literal["resource", b"resource"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "instrumentation_library_logs",
            b"instrumentation_library_logs",
            "resource",
            b"resource",
        ],
    ) -> None: ...

type___ResourceLogs = ResourceLogs

class InstrumentationLibraryLogs(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def instrumentation_library(
        self,
    ) -> opentelemetry___proto___common___v1___common_pb2___InstrumentationLibrary: ...
    @property
    def logs(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___LogRecord
    ]: ...
    def __init__(
        self,
        *,
        instrumentation_library: typing___Optional[
            opentelemetry___proto___common___v1___common_pb2___InstrumentationLibrary
        ] = None,
        logs: typing___Optional[typing___Iterable[type___LogRecord]] = None,
    ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(
            cls, s: builtin___bytes
        ) -> InstrumentationLibraryLogs: ...
    else:
        @classmethod
        def FromString(
            cls,
            s: typing___Union[
                builtin___bytes, builtin___buffer, builtin___unicode
            ],
        ) -> InstrumentationLibraryLogs: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "instrumentation_library", b"instrumentation_library"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "instrumentation_library",
            b"instrumentation_library",
            "logs",
            b"logs",
        ],
    ) -> None: ...

type___InstrumentationLibraryLogs = InstrumentationLibraryLogs

class LogRecord(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    time_unix_nano: builtin___int = ...
    severity_number: type___SeverityNumberValue = ...
    severity_text: typing___Text = ...
    name: typing___Text = ...
    dropped_attributes_count: builtin___int = ...
    flags: builtin___int = ...
    trace_id: builtin___bytes = ...
    span_id: builtin___bytes = ...
    @property
    def body(
        self,
    ) -> opentelemetry___proto___common___v1___common_pb2___AnyValue: ...
    @property
    def attributes(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        opentelemetry___proto___common___v1___common_pb2___KeyValue
    ]: ...
    def __init__(
        self,
        *,
        time_unix_nano: typing___Optional[builtin___int] = None,
        severity_number: typing___Optional[type___SeverityNumberValue] = None,
        severity_text: typing___Optional[typing___Text] = None,
        name: typing___Optional[typing___Text] = None,
        body: typing___Optional[
            opentelemetry___proto___common___v1___common_pb2___AnyValue
        ] = None,
        attributes: typing___Optional[
            typing___Iterable[
                opentelemetry___proto___common___v1___common_pb2___KeyValue
            ]
        ] = None,
        dropped_attributes_count: typing___Optional[builtin___int] = None,
        flags: typing___Optional[builtin___int] = None,
        trace_id: typing___Optional[builtin___bytes] = None,
        span_id: typing___Optional[builtin___bytes] = None,
    ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> LogRecord: ...
    else:
        @classmethod
        def FromString(
            cls,
            s: typing___Union[
                builtin___bytes, builtin___buffer, builtin___unicode
            ],
        ) -> LogRecord: ...
    def HasField(
        self, field_name: typing_extensions___Literal["body", b"body"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "attributes",
            b"attributes",
            "body",
            b"body",
            "dropped_attributes_count",
            b"dropped_attributes_count",
            "flags",
            b"flags",
            "name",
            b"name",
            "severity_number",
            b"severity_number",
            "severity_text",
            b"severity_text",
            "span_id",
            b"span_id",
            "time_unix_nano",
            b"time_unix_nano",
            "trace_id",
            b"trace_id",
        ],
    ) -> None: ...

type___LogRecord = LogRecord



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from opentelemetry.proto.resource.v1.resource_pb2 import (
    Resource as opentelemetry___proto___resource___v1___resource_pb2___Resource,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MetricConfigRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    last_known_fingerprint: builtin___bytes = ...

    @property
    def resource(self) -> opentelemetry___proto___resource___v1___resource_pb2___Resource: ...

    def __init__(self,
        *,
        resource : typing___Optional[opentelemetry___proto___resource___v1___resource_pb2___Resource] = None,
        last_known_fingerprint : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MetricConfigRequest: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MetricConfigRequest: ...
    def HasField(self, field_name: typing_extensions___Literal[u"resource",b"resource"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"last_known_fingerprint",b"last_known_fingerprint",u"resource",b"resource"]) -> None: ...
type___MetricConfigRequest = MetricConfigRequest

class MetricConfigResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class Schedule(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        class Pattern(google___protobuf___message___Message):
            DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
            equals: typing___Text = ...
            starts_with: typing___Text = ...

            def __init__(self,
                *,
                equals : typing___Optional[typing___Text] = None,
                starts_with : typing___Optional[typing___Text] = None,
                ) -> None: ...
            if sys.version_info >= (3,):
                @classmethod
                def FromString(cls, s: builtin___bytes) -> MetricConfigResponse.Schedule.Pattern: ...
            else:
                @classmethod
                def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MetricConfigResponse.Schedule.Pattern: ...
            def HasField(self, field_name: typing_extensions___Literal[u"equals",b"equals",u"match",b"match",u"starts_with",b"starts_with"]) -> builtin___bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"equals",b"equals",u"match",b"match",u"starts_with",b"starts_with"]) -> None: ...
            def WhichOneof(self, oneof_group: typing_extensions___Literal[u"match",b"match"]) -> typing_extensions___Literal["equals","starts_with"]: ...
        type___Pattern = Pattern

        period_sec: builtin___int = ...

        @property
        def exclusion_patterns(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___MetricConfigResponse.Schedule.Pattern]: ...

        @property
        def inclusion_patterns(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___MetricConfigResponse.Schedule.Pattern]: ...

        def __init__(self,
            *,
            exclusion_patterns : typing___Optional[typing___Iterable[type___MetricConfigResponse.Schedule.Pattern]] = None,
            inclusion_patterns : typing___Optional[typing___Iterable[type___MetricConfigResponse.Schedule.Pattern]] = None,
            period_sec : typing___Optional[builtin___int] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> MetricConfigResponse.Schedule: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MetricConfigResponse.Schedule: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"exclusion_patterns",b"exclusion_patterns",u"inclusion_patterns",b"inclusion_patterns",u"period_sec",b"period_sec"]) -> None: ...
    type___Schedule = Schedule

    fingerprint: builtin___bytes = ...
    suggested_wait_time_sec: builtin___int = ...

    @property
    def schedules(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___MetricConfigResponse.Schedule]: ...

    def __init__(self,
        *,
        fingerprint : typing___Optional[builtin___bytes] = None,
        schedules : typing___Optional[typing___Iterable[type___MetricConfigResponse.Schedule]] = None,
        suggested_wait_time_sec : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MetricConfigResponse: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MetricConfigResponse: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"fingerprint",b"fingerprint",u"schedules",b"schedules",u"suggested_wait_time_sec",b"suggested_wait_time_sec"]) -> None: ...
type___MetricConfigResponse = MetricConfigResponse



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AnyValue(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    string_value: typing___Text = ...
    bool_value: builtin___bool = ...
    int_value: builtin___int = ...
    double_value: builtin___float = ...

    @property
    def array_value(self) -> type___ArrayValue: ...

    @property
    def kvlist_value(self) -> type___KeyValueList: ...

    def __init__(self,
        *,
        string_value : typing___Optional[typing___Text] = None,
        bool_value : typing___Optional[builtin___bool] = None,
        int_value : typing___Optional[builtin___int] = None,
        double_value : typing___Optional[builtin___float] = None,
        array_value : typing___Optional[type___ArrayValue] = None,
        kvlist_value : typing___Optional[type___KeyValueList] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> AnyValue: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> AnyValue: ...
    def HasField(self, field_name: typing_extensions___Literal[u"array_value",b"array_value",u"bool_value",b"bool_value",u"double_value",b"double_value",u"int_value",b"int_value",u"kvlist_value",b"kvlist_value",u"string_value",b"string_value",u"value",b"value"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"array_value",b"array_value",u"bool_value",b"bool_value",u"double_value",b"double_value",u"int_value",b"int_value",u"kvlist_value",b"kvlist_value",u"string_value",b"string_value",u"value",b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"value",b"value"]) -> typing_extensions___Literal["string_value","bool_value","int_value","double_value","array_value","kvlist_value"]: ...
type___AnyValue = AnyValue

class ArrayValue(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def values(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___AnyValue]: ...

    def __init__(self,
        *,
        values : typing___Optional[typing___Iterable[type___AnyValue]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> ArrayValue: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> ArrayValue: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"values",b"values"]) -> None: ...
type___ArrayValue = ArrayValue

class KeyValueList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def values(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___KeyValue]: ...

    def __init__(self,
        *,
        values : typing___Optional[typing___Iterable[type___KeyValue]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> KeyValueList: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> KeyValueList: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"values",b"values"]) -> None: ...
type___KeyValueList = KeyValueList

class KeyValue(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    key: typing___Text = ...

    @property
    def value(self) -> type___AnyValue: ...

    def __init__(self,
        *,
        key : typing___Optional[typing___Text] = None,
        value : typing___Optional[type___AnyValue] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> KeyValue: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> KeyValue: ...
    def HasField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"key",b"key",u"value",b"value"]) -> None: ...
type___KeyValue = KeyValue

class StringKeyValue(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    key: typing___Text = ...
    value: typing___Text = ...

    def __init__(self,
        *,
        key : typing___Optional[typing___Text] = None,
        value : typing___Optional[typing___Text] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> StringKeyValue: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> StringKeyValue: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"key",b"key",u"value",b"value"]) -> None: ...
type___StringKeyValue = StringKeyValue

class InstrumentationLibrary(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    name: typing___Text = ...
    version: typing___Text = ...

    def __init__(self,
        *,
        name : typing___Optional[typing___Text] = None,
        version : typing___Optional[typing___Text] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> InstrumentationLibrary: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> InstrumentationLibrary: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"name",b"name",u"version",b"version"]) -> None: ...
type___InstrumentationLibrary = InstrumentationLibrary



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opentelemetry/proto/metrics/v1/metrics.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opentelemetry.proto.common.v1 import common_pb2 as opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2
from opentelemetry.proto.resource.v1 import resource_pb2 as opentelemetry_dot_proto_dot_resource_dot_v1_dot_resource__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opentelemetry/proto/metrics/v1/metrics.proto',
  package='opentelemetry.proto.metrics.v1',
  syntax='proto3',
  serialized_options=b'\n!io.opentelemetry.proto.metrics.v1B\014MetricsProtoP\001Z?github.com/open-telemetry/opentelemetry-proto/gen/go/metrics/v1',
  serialized_pb=b'\n,opentelemetry/proto/metrics/v1/metrics.proto\x12\x1eopentelemetry.proto.metrics.v1\x1a*opentelemetry/proto/common/v1/common.proto\x1a.opentelemetry/proto/resource/v1/resource.proto\"\xb6\x01\n\x0fResourceMetrics\x12;\n\x08resource\x18\x01 \x01(\x0b\x32).opentelemetry.proto.resource.v1.Resource\x12\x66\n\x1finstrumentation_library_metrics\x18\x02 \x03(\x0b\x32=.opentelemetry.proto.metrics.v1.InstrumentationLibraryMetrics\"\xb0\x01\n\x1dInstrumentationLibraryMetrics\x12V\n\x17instrumentation_library\x18\x01 \x01(\x0b\x32\x35.opentelemetry.proto.common.v1.InstrumentationLibrary\x12\x37\n\x07metrics\x18\x02 \x03(\x0b\x32&.opentelemetry.proto.metrics.v1.Metric\"\xd5\x03\n\x06Metric\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04unit\x18\x03 \x01(\t\x12=\n\tint_gauge\x18\x04 \x01(\x0b\x32(.opentelemetry.proto.metrics.v1.IntGaugeH\x00\x12\x43\n\x0c\x64ouble_gauge\x18\x05 \x01(\x0b\x32+.opentelemetry.proto.metrics.v1.DoubleGaugeH\x00\x12\x39\n\x07int_sum\x18\x06 \x01(\x0b\x32&.opentelemetry.proto.metrics.v1.IntSumH\x00\x12?\n\ndouble_sum\x18\x07 \x01(\x0b\x32).opentelemetry.proto.metrics.v1.DoubleSumH\x00\x12\x45\n\rint_histogram\x18\x08 \x01(\x0b\x32,.opentelemetry.proto.metrics.v1.IntHistogramH\x00\x12K\n\x10\x64ouble_histogram\x18\t \x01(\x0b\x32/.opentelemetry.proto.metrics.v1.DoubleHistogramH\x00\x42\x06\n\x04\x64\x61ta\"M\n\x08IntGauge\x12\x41\n\x0b\x64\x61ta_points\x18\x01 \x03(\x0b\x32,.opentelemetry.proto.metrics.v1.IntDataPoint\"S\n\x0b\x44oubleGauge\x12\x44\n\x0b\x64\x61ta_points\x18\x01 \x03(\x0b\x32/.opentelemetry.proto.metrics.v1.DoubleDataPoint\"\xba\x01\n\x06IntSum\x12\x41\n\x0b\x64\x61ta_points\x18\x01 \x03(\x0b\x32,.opentelemetry.proto.metrics.v1.IntDataPoint\x12W\n\x17\x61ggregation_temporality\x18\x02 \x01(\x0e\x32\x36.opentelemetry.proto.metrics.v1.AggregationTemporality\x12\x14\n\x0cis_monotonic\x18\x03 \x01(\x08\"\xc0\x01\n\tDoubleSum\x12\x44\n\x0b\x64\x61ta_points\x18\x01 \x03(\x0b\x32/.opentelemetry.proto.metrics.v1.DoubleDataPoint\x12W\n\x17\x61ggregation_temporality\x18\x02 \x01(\x0e\x32\x36.opentelemetry.proto.metrics.v1.AggregationTemporality\x12\x14\n\x0cis_monotonic\x18\x03 \x01(\x08\"\xb3\x01\n\x0cIntHistogram\x12J\n\x0b\x64\x61ta_points\x18\x01 \x03(\x0b\x32\x35.opentelemetry.proto.metrics.v1.IntHistogramDataPoint\x12W\n\x17\x61ggregation_temporality\x18\x02 \x01(\x0e\x32\x36.opentelemetry.proto.metrics.v1.AggregationTemporality\"\xb9\x01\n\x0f\x44oubleHistogram\x12M\n\x0b\x64\x61ta_points\x18\x01 \x03(\x0b\x32\x38.opentelemetry.proto.metrics.v1.DoubleHistogramDataPoint\x12W\n\x17\x61ggregation_temporality\x18\x02 \x01(\x0e\x32\x36.opentelemetry.proto.metrics.v1.AggregationTemporality\"\xd2\x01\n\x0cIntDataPoint\x12=\n\x06labels\x18\x01 \x03(\x0b\x32-.opentelemetry.proto.common.v1.StringKeyValue\x12\x1c\n\x14start_time_unix_nano\x18\x02 \x01(\x06\x12\x16\n\x0etime_unix_nano\x18\x03 \x01(\x06\x12\r\n\x05value\x18\x04 \x01(\x10\x12>\n\texemplars\x18\x05 \x03(\x0b\x32+.opentelemetry.proto.metrics.v1.IntExemplar\"\xd8\x01\n\x0f\x44oubleDataPoint\x12=\n\x06labels\x18\x01 \x03(\x0b\x32-.opentelemetry.proto.common.v1.StringKeyValue\x12\x1c\n\x14start_time_unix_nano\x18\x02 \x01(\x06\x12\x16\n\x0etime_unix_nano\x18\x03 \x01(\x06\x12\r\n\x05value\x18\x04 \x01(\x01\x12\x41\n\texemplars\x18\x05 \x03(\x0b\x32..opentelemetry.proto.metrics.v1.DoubleExemplar\"\x98\x02\n\x15IntHistogramDataPoint\x12=\n\x06labels\x18\x01 \x03(\x0b\x32-.opentelemetry.proto.common.v1.StringKeyValue\x12\x1c\n\x14start_time_unix_nano\x18\x02 \x01(\x06\x12\x16\n\x0etime_unix_nano\x18\x03 \x01(\x06\x12\r\n\x05\x63ount\x18\x04 \x01(\x06\x12\x0b\n\x03sum\x18\x05 \x01(\x10\x12\x15\n\rbucket_counts\x18\x06 \x03(\x06\x12\x17\n\x0f\x65xplicit_bounds\x18\x07 \x03(\x01\x12>\n\texemplars\x18\x08 \x03(\x0b\x32+.opentelemetry.proto.metrics.v1.IntExemplar\"\x9e\x02\n\x18\x44oubleHistogramDataPoint\x12=\n\x06labels\x18\x01 \x03(\x0b\x32-.opentelemetry.proto.common.v1.StringKeyValue\x12\x1c\n\x14start_time_unix_nano\x18\x02 \x01(\x06\x12\x16\n\x0etime_unix_nano\x18\x03 \x01(\x06\x12\r\n\x05\x63ount\x18\x04 \x01(\x06\x12\x0b\n\x03sum\x18\x05 \x01(\x01\x12\x15\n\rbucket_counts\x18\x06 \x03(\x06\x12\x17\n\x0f\x65xplicit_bounds\x18\x07 \x03(\x01\x12\x41\n\texemplars\x18\x08 \x03(\x0b\x32..opentelemetry.proto.metrics.v1.DoubleExemplar\"\x9f\x01\n\x0bIntExemplar\x12\x46\n\x0f\x66iltered_labels\x18\x01 \x03(\x0b\x32-.opentelemetry.proto.common.v1.StringKeyValue\x12\x16\n\x0etime_unix_nano\x18\x02 \x01(\x06\x12\r\n\x05value\x18\x03 \x01(\x10\x12\x0f\n\x07span_id\x18\x04 \x01(\x0c\x12\x10\n\x08trace_id\x18\x05 \x01(\x0c\"\xa2\x01\n\x0e\x44oubleExemplar\x12\x46\n\x0f\x66iltered_labels\x18\x01 \x03(\x0b\x32-.opentelemetry.proto.common.v1.StringKeyValue\x12\x16\n\x0etime_unix_nano\x18\x02 \x01(\x06\x12\r\n\x05value\x18\x03 \x01(\x01\x12\x0f\n\x07span_id\x18\x04 \x01(\x0c\x12\x10\n\x08trace_id\x18\x05 \x01(\x0c*\x8c\x01\n\x16\x41ggregationTemporality\x12\'\n#AGGREGATION_TEMPORALITY_UNSPECIFIED\x10\x00\x12!\n\x1d\x41GGREGATION_TEMPORALITY_DELTA\x10\x01\x12&\n\"AGGREGATION_TEMPORALITY_CUMULATIVE\x10\x02\x42t\n!io.opentelemetry.proto.metrics.v1B\x0cMetricsProtoP\x01Z?github.com/open-telemetry/opentelemetry-proto/gen/go/metrics/v1b\x06proto3'
  ,
  dependencies=[opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,opentelemetry_dot_proto_dot_resource_dot_v1_dot_resource__pb2.DESCRIPTOR,])

_AGGREGATIONTEMPORALITY = _descriptor.EnumDescriptor(
  name='AggregationTemporality',
  full_name='opentelemetry.proto.metrics.v1.AggregationTemporality',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_TEMPORALITY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_TEMPORALITY_DELTA', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_TEMPORALITY_CUMULATIVE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3258,
  serialized_end=3398,
)
_sym_db.RegisterEnumDescriptor(_AGGREGATIONTEMPORALITY)

AggregationTemporality = enum_type_wrapper.EnumTypeWrapper(_AGGREGATIONTEMPORALITY)
AGGREGATION_TEMPORALITY_UNSPECIFIED = 0
AGGREGATION_TEMPORALITY_DELTA = 1
AGGREGATION_TEMPORALITY_CUMULATIVE = 2



_RESOURCEMETRICS = _descriptor.Descriptor(
  name='ResourceMetrics',
  full_name='opentelemetry.proto.metrics.v1.ResourceMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='opentelemetry.proto.metrics.v1.ResourceMetrics.resource', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instrumentation_library_metrics', full_name='opentelemetry.proto.metrics.v1.ResourceMetrics.instrumentation_library_metrics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=355,
)


_INSTRUMENTATIONLIBRARYMETRICS = _descriptor.Descriptor(
  name='InstrumentationLibraryMetrics',
  full_name='opentelemetry.proto.metrics.v1.InstrumentationLibraryMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instrumentation_library', full_name='opentelemetry.proto.metrics.v1.InstrumentationLibraryMetrics.instrumentation_library', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='opentelemetry.proto.metrics.v1.InstrumentationLibraryMetrics.metrics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=534,
)


_METRIC = _descriptor.Descriptor(
  name='Metric',
  full_name='opentelemetry.proto.metrics.v1.Metric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opentelemetry.proto.metrics.v1.Metric.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='opentelemetry.proto.metrics.v1.Metric.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='opentelemetry.proto.metrics.v1.Metric.unit', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_gauge', full_name='opentelemetry.proto.metrics.v1.Metric.int_gauge', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_gauge', full_name='opentelemetry.proto.metrics.v1.Metric.double_gauge', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_sum', full_name='opentelemetry.proto.metrics.v1.Metric.int_sum', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_sum', full_name='opentelemetry.proto.metrics.v1.Metric.double_sum', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_histogram', full_name='opentelemetry.proto.metrics.v1.Metric.int_histogram', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_histogram', full_name='opentelemetry.proto.metrics.v1.Metric.double_histogram', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='opentelemetry.proto.metrics.v1.Metric.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=537,
  serialized_end=1006,
)


_INTGAUGE = _descriptor.Descriptor(
  name='IntGauge',
  full_name='opentelemetry.proto.metrics.v1.IntGauge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_points', full_name='opentelemetry.proto.metrics.v1.IntGauge.data_points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1008,
  serialized_end=1085,
)


_DOUBLEGAUGE = _descriptor.Descriptor(
  name='DoubleGauge',
  full_name='opentelemetry.proto.metrics.v1.DoubleGauge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_points', full_name='opentelemetry.proto.metrics.v1.DoubleGauge.data_points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1087,
  serialized_end=1170,
)


_INTSUM = _descriptor.Descriptor(
  name='IntSum',
  full_name='opentelemetry.proto.metrics.v1.IntSum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_points', full_name='opentelemetry.proto.metrics.v1.IntSum.data_points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aggregation_temporality', full_name='opentelemetry.proto.metrics.v1.IntSum.aggregation_temporality', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_monotonic', full_name='opentelemetry.proto.metrics.v1.IntSum.is_monotonic', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1173,
  serialized_end=1359,
)


_DOUBLESUM = _descriptor.Descriptor(
  name='DoubleSum',
  full_name='opentelemetry.proto.metrics.v1.DoubleSum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_points', full_name='opentelemetry.proto.metrics.v1.DoubleSum.data_points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aggregation_temporality', full_name='opentelemetry.proto.metrics.v1.DoubleSum.aggregation_temporality', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_monotonic', full_name='opentelemetry.proto.metrics.v1.DoubleSum.is_monotonic', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1362,
  serialized_end=1554,
)


_INTHISTOGRAM = _descriptor.Descriptor(
  name='IntHistogram',
  full_name='opentelemetry.proto.metrics.v1.IntHistogram',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_points', full_name='opentelemetry.proto.metrics.v1.IntHistogram.data_points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aggregation_temporality', full_name='opentelemetry.proto.metrics.v1.IntHistogram.aggregation_temporality', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1736,
)


_DOUBLEHISTOGRAM = _descriptor.Descriptor(
  name='DoubleHistogram',
  full_name='opentelemetry.proto.metrics.v1.DoubleHistogram',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_points', full_name='opentelemetry.proto.metrics.v1.DoubleHistogram.data_points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aggregation_temporality', full_name='opentelemetry.proto.metrics.v1.DoubleHistogram.aggregation_temporality', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1739,
  serialized_end=1924,
)


_INTDATAPOINT = _descriptor.Descriptor(
  name='IntDataPoint',
  full_name='opentelemetry.proto.metrics.v1.IntDataPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='labels', full_name='opentelemetry.proto.metrics.v1.IntDataPoint.labels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time_unix_nano', full_name='opentelemetry.proto.metrics.v1.IntDataPoint.start_time_unix_nano', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_unix_nano', full_name='opentelemetry.proto.metrics.v1.IntDataPoint.time_unix_nano', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='opentelemetry.proto.metrics.v1.IntDataPoint.value', index=3,
      number=4, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exemplars', full_name='opentelemetry.proto.metrics.v1.IntDataPoint.exemplars', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1927,
  serialized_end=2137,
)


_DOUBLEDATAPOINT = _descriptor.Descriptor(
  name='DoubleDataPoint',
  full_name='opentelemetry.proto.metrics.v1.DoubleDataPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='labels', full_name='opentelemetry.proto.metrics.v1.DoubleDataPoint.labels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time_unix_nano', full_name='opentelemetry.proto.metrics.v1.DoubleDataPoint.start_time_unix_nano', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_unix_nano', full_name='opentelemetry.proto.metrics.v1.DoubleDataPoint.time_unix_nano', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='opentelemetry.proto.metrics.v1.DoubleDataPoint.value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exemplars', full_name='opentelemetry.proto.metrics.v1.DoubleDataPoint.exemplars', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2140,
  serialized_end=2356,
)


_INTHISTOGRAMDATAPOINT = _descriptor.Descriptor(
  name='IntHistogramDataPoint',
  full_name='opentelemetry.proto.metrics.v1.IntHistogramDataPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='labels', full_name='opentelemetry.proto.metrics.v1.IntHistogramDataPoint.labels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time_unix_nano', full_name='opentelemetry.proto.metrics.v1.IntHistogramDataPoint.start_time_unix_nano', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_unix_nano', full_name='opentelemetry.proto.metrics.v1.IntHistogramDataPoint.time_unix_nano', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='opentelemetry.proto.metrics.v1.IntHistogramDataPoint.count', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sum', full_name='opentelemetry.proto.metrics.v1.IntHistogramDataPoint.sum', index=4,
      number=5, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket_counts', full_name='opentelemetry.proto.metrics.v1.IntHistogramDataPoint.bucket_counts', index=5,
      number=6, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='explicit_bounds', full_name='opentelemetry.proto.metrics.v1.IntHistogramDataPoint.explicit_bounds', index=6,
      number=7, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exemplars', full_name='opentelemetry.proto.metrics.v1.IntHistogramDataPoint.exemplars', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2359,
  serialized_end=2639,
)


_DOUBLEHISTOGRAMDATAPOINT = _descriptor.Descriptor(
  name='DoubleHistogramDataPoint',
  full_name='opentelemetry.proto.metrics.v1.DoubleHistogramDataPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='labels', full_name='opentelemetry.proto.metrics.v1.DoubleHistogramDataPoint.labels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time_unix_nano', full_name='opentelemetry.proto.metrics.v1.DoubleHistogramDataPoint.start_time_unix_nano', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_unix_nano', full_name='opentelemetry.proto.metrics.v1.DoubleHistogramDataPoint.time_unix_nano', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='opentelemetry.proto.metrics.v1.DoubleHistogramDataPoint.count', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sum', full_name='opentelemetry.proto.metrics.v1.DoubleHistogramDataPoint.sum', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket_counts', full_name='opentelemetry.proto.metrics.v1.DoubleHistogramDataPoint.bucket_counts', index=5,
      number=6, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='explicit_bounds', full_name='opentelemetry.proto.metrics.v1.DoubleHistogramDataPoint.explicit_bounds', index=6,
      number=7, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exemplars', full_name='opentelemetry.proto.metrics.v1.DoubleHistogramDataPoint.exemplars', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2642,
  serialized_end=2928,
)


_INTEXEMPLAR = _descriptor.Descriptor(
  name='IntExemplar',
  full_name='opentelemetry.proto.metrics.v1.IntExemplar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filtered_labels', full_name='opentelemetry.proto.metrics.v1.IntExemplar.filtered_labels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_unix_nano', full_name='opentelemetry.proto.metrics.v1.IntExemplar.time_unix_nano', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='opentelemetry.proto.metrics.v1.IntExemplar.value', index=2,
      number=3, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='span_id', full_name='opentelemetry.proto.metrics.v1.IntExemplar.span_id', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trace_id', full_name='opentelemetry.proto.metrics.v1.IntExemplar.trace_id', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2931,
  serialized_end=3090,
)


_DOUBLEEXEMPLAR = _descriptor.Descriptor(
  name='DoubleExemplar',
  full_name='opentelemetry.proto.metrics.v1.DoubleExemplar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filtered_labels', full_name='opentelemetry.proto.metrics.v1.DoubleExemplar.filtered_labels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_unix_nano', full_name='opentelemetry.proto.metrics.v1.DoubleExemplar.time_unix_nano', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='opentelemetry.proto.metrics.v1.DoubleExemplar.value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='span_id', full_name='opentelemetry.proto.metrics.v1.DoubleExemplar.span_id', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trace_id', full_name='opentelemetry.proto.metrics.v1.DoubleExemplar.trace_id', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3093,
  serialized_end=3255,
)

_RESOURCEMETRICS.fields_by_name['resource'].message_type = opentelemetry_dot_proto_dot_resource_dot_v1_dot_resource__pb2._RESOURCE
_RESOURCEMETRICS.fields_by_name['instrumentation_library_metrics'].message_type = _INSTRUMENTATIONLIBRARYMETRICS
_INSTRUMENTATIONLIBRARYMETRICS.fields_by_name['instrumentation_library'].message_type = opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2._INSTRUMENTATIONLIBRARY
_INSTRUMENTATIONLIBRARYMETRICS.fields_by_name['metrics'].message_type = _METRIC
_METRIC.fields_by_name['int_gauge'].message_type = _INTGAUGE
_METRIC.fields_by_name['double_gauge'].message_type = _DOUBLEGAUGE
_METRIC.fields_by_name['int_sum'].message_type = _INTSUM
_METRIC.fields_by_name['double_sum'].message_type = _DOUBLESUM
_METRIC.fields_by_name['int_histogram'].message_type = _INTHISTOGRAM
_METRIC.fields_by_name['double_histogram'].message_type = _DOUBLEHISTOGRAM
_METRIC.oneofs_by_name['data'].fields.append(
  _METRIC.fields_by_name['int_gauge'])
_METRIC.fields_by_name['int_gauge'].containing_oneof = _METRIC.oneofs_by_name['data']
_METRIC.oneofs_by_name['data'].fields.append(
  _METRIC.fields_by_name['double_gauge'])
_METRIC.fields_by_name['double_gauge'].containing_oneof = _METRIC.oneofs_by_name['data']
_METRIC.oneofs_by_name['data'].fields.append(
  _METRIC.fields_by_name['int_sum'])
_METRIC.fields_by_name['int_sum'].containing_oneof = _METRIC.oneofs_by_name['data']
_METRIC.oneofs_by_name['data'].fields.append(
  _METRIC.fields_by_name['double_sum'])
_METRIC.fields_by_name['double_sum'].containing_oneof = _METRIC.oneofs_by_name['data']
_METRIC.oneofs_by_name['data'].fields.append(
  _METRIC.fields_by_name['int_histogram'])
_METRIC.fields_by_name['int_histogram'].containing_oneof = _METRIC.oneofs_by_name['data']
_METRIC.oneofs_by_name['data'].fields.append(
  _METRIC.fields_by_name['double_histogram'])
_METRIC.fields_by_name['double_histogram'].containing_oneof = _METRIC.oneofs_by_name['data']
_INTGAUGE.fields_by_name['data_points'].message_type = _INTDATAPOINT
_DOUBLEGAUGE.fields_by_name['data_points'].message_type = _DOUBLEDATAPOINT
_INTSUM.fields_by_name['data_points'].message_type = _INTDATAPOINT
_INTSUM.fields_by_name['aggregation_temporality'].enum_type = _AGGREGATIONTEMPORALITY
_DOUBLESUM.fields_by_name['data_points'].message_type = _DOUBLEDATAPOINT
_DOUBLESUM.fields_by_name['aggregation_temporality'].enum_type = _AGGREGATIONTEMPORALITY
_INTHISTOGRAM.fields_by_name['data_points'].message_type = _INTHISTOGRAMDATAPOINT
_INTHISTOGRAM.fields_by_name['aggregation_temporality'].enum_type = _AGGREGATIONTEMPORALITY
_DOUBLEHISTOGRAM.fields_by_name['data_points'].message_type = _DOUBLEHISTOGRAMDATAPOINT
_DOUBLEHISTOGRAM.fields_by_name['aggregation_temporality'].enum_type = _AGGREGATIONTEMPORALITY
_INTDATAPOINT.fields_by_name['labels'].message_type = opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2._STRINGKEYVALUE
_INTDATAPOINT.fields_by_name['exemplars'].message_type = _INTEXEMPLAR
_DOUBLEDATAPOINT.fields_by_name['labels'].message_type = opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2._STRINGKEYVALUE
_DOUBLEDATAPOINT.fields_by_name['exemplars'].message_type = _DOUBLEEXEMPLAR
_INTHISTOGRAMDATAPOINT.fields_by_name['labels'].message_type = opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2._STRINGKEYVALUE
_INTHISTOGRAMDATAPOINT.fields_by_name['exemplars'].message_type = _INTEXEMPLAR
_DOUBLEHISTOGRAMDATAPOINT.fields_by_name['labels'].message_type = opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2._STRINGKEYVALUE
_DOUBLEHISTOGRAMDATAPOINT.fields_by_name['exemplars'].message_type = _DOUBLEEXEMPLAR
_INTEXEMPLAR.fields_by_name['filtered_labels'].message_type = opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2._STRINGKEYVALUE
_DOUBLEEXEMPLAR.fields_by_name['filtered_labels'].message_type = opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2._STRINGKEYVALUE
DESCRIPTOR.message_types_by_name['ResourceMetrics'] = _RESOURCEMETRICS
DESCRIPTOR.message_types_by_name['InstrumentationLibraryMetrics'] = _INSTRUMENTATIONLIBRARYMETRICS
DESCRIPTOR.message_types_by_name['Metric'] = _METRIC
DESCRIPTOR.message_types_by_name['IntGauge'] = _INTGAUGE
DESCRIPTOR.message_types_by_name['DoubleGauge'] = _DOUBLEGAUGE
DESCRIPTOR.message_types_by_name['IntSum'] = _INTSUM
DESCRIPTOR.message_types_by_name['DoubleSum'] = _DOUBLESUM
DESCRIPTOR.message_types_by_name['IntHistogram'] = _INTHISTOGRAM
DESCRIPTOR.message_types_by_name['DoubleHistogram'] = _DOUBLEHISTOGRAM
DESCRIPTOR.message_types_by_name['IntDataPoint'] = _INTDATAPOINT
DESCRIPTOR.message_types_by_name['DoubleDataPoint'] = _DOUBLEDATAPOINT
DESCRIPTOR.message_types_by_name['IntHistogramDataPoint'] = _INTHISTOGRAMDATAPOINT
DESCRIPTOR.message_types_by_name['DoubleHistogramDataPoint'] = _DOUBLEHISTOGRAMDATAPOINT
DESCRIPTOR.message_types_by_name['IntExemplar'] = _INTEXEMPLAR
DESCRIPTOR.message_types_by_name['DoubleExemplar'] = _DOUBLEEXEMPLAR
DESCRIPTOR.enum_types_by_name['AggregationTemporality'] = _AGGREGATIONTEMPORALITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ResourceMetrics = _reflection.GeneratedProtocolMessageType('ResourceMetrics', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEMETRICS,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.ResourceMetrics)
  })
_sym_db.RegisterMessage(ResourceMetrics)

InstrumentationLibraryMetrics = _reflection.GeneratedProtocolMessageType('InstrumentationLibraryMetrics', (_message.Message,), {
  'DESCRIPTOR' : _INSTRUMENTATIONLIBRARYMETRICS,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.InstrumentationLibraryMetrics)
  })
_sym_db.RegisterMessage(InstrumentationLibraryMetrics)

Metric = _reflection.GeneratedProtocolMessageType('Metric', (_message.Message,), {
  'DESCRIPTOR' : _METRIC,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.Metric)
  })
_sym_db.RegisterMessage(Metric)

IntGauge = _reflection.GeneratedProtocolMessageType('IntGauge', (_message.Message,), {
  'DESCRIPTOR' : _INTGAUGE,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.IntGauge)
  })
_sym_db.RegisterMessage(IntGauge)

DoubleGauge = _reflection.GeneratedProtocolMessageType('DoubleGauge', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEGAUGE,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.DoubleGauge)
  })
_sym_db.RegisterMessage(DoubleGauge)

IntSum = _reflection.GeneratedProtocolMessageType('IntSum', (_message.Message,), {
  'DESCRIPTOR' : _INTSUM,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.IntSum)
  })
_sym_db.RegisterMessage(IntSum)

DoubleSum = _reflection.GeneratedProtocolMessageType('DoubleSum', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLESUM,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.DoubleSum)
  })
_sym_db.RegisterMessage(DoubleSum)

IntHistogram = _reflection.GeneratedProtocolMessageType('IntHistogram', (_message.Message,), {
  'DESCRIPTOR' : _INTHISTOGRAM,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.IntHistogram)
  })
_sym_db.RegisterMessage(IntHistogram)

DoubleHistogram = _reflection.GeneratedProtocolMessageType('DoubleHistogram', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEHISTOGRAM,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.DoubleHistogram)
  })
_sym_db.RegisterMessage(DoubleHistogram)

IntDataPoint = _reflection.GeneratedProtocolMessageType('IntDataPoint', (_message.Message,), {
  'DESCRIPTOR' : _INTDATAPOINT,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.IntDataPoint)
  })
_sym_db.RegisterMessage(IntDataPoint)

DoubleDataPoint = _reflection.GeneratedProtocolMessageType('DoubleDataPoint', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEDATAPOINT,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.DoubleDataPoint)
  })
_sym_db.RegisterMessage(DoubleDataPoint)

IntHistogramDataPoint = _reflection.GeneratedProtocolMessageType('IntHistogramDataPoint', (_message.Message,), {
  'DESCRIPTOR' : _INTHISTOGRAMDATAPOINT,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.IntHistogramDataPoint)
  })
_sym_db.RegisterMessage(IntHistogramDataPoint)

DoubleHistogramDataPoint = _reflection.GeneratedProtocolMessageType('DoubleHistogramDataPoint', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEHISTOGRAMDATAPOINT,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.DoubleHistogramDataPoint)
  })
_sym_db.RegisterMessage(DoubleHistogramDataPoint)

IntExemplar = _reflection.GeneratedProtocolMessageType('IntExemplar', (_message.Message,), {
  'DESCRIPTOR' : _INTEXEMPLAR,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.IntExemplar)
  })
_sym_db.RegisterMessage(IntExemplar)

DoubleExemplar = _reflection.GeneratedProtocolMessageType('DoubleExemplar', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEEXEMPLAR,
  '__module__' : 'opentelemetry.proto.metrics.v1.metrics_pb2'
  # @@protoc_insertion_point(class_scope:opentelemetry.proto.metrics.v1.DoubleExemplar)
  })
_sym_db.RegisterMessage(DoubleExemplar)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    NewType as typing___NewType,
    Optional as typing___Optional,
    Tuple as typing___Tuple,
    Union as typing___Union,
    cast as typing___cast,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
builtin___str = str
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class TraceConfig(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    max_number_of_attributes: builtin___int = ...
    max_number_of_timed_events: builtin___int = ...
    max_number_of_attributes_per_timed_event: builtin___int = ...
    max_number_of_links: builtin___int = ...
    max_number_of_attributes_per_link: builtin___int = ...

    @property
    def constant_sampler(self) -> type___ConstantSampler: ...

    @property
    def probability_sampler(self) -> type___ProbabilitySampler: ...

    @property
    def rate_limiting_sampler(self) -> type___RateLimitingSampler: ...

    def __init__(self,
        *,
        constant_sampler : typing___Optional[type___ConstantSampler] = None,
        probability_sampler : typing___Optional[type___ProbabilitySampler] = None,
        rate_limiting_sampler : typing___Optional[type___RateLimitingSampler] = None,
        max_number_of_attributes : typing___Optional[builtin___int] = None,
        max_number_of_timed_events : typing___Optional[builtin___int] = None,
        max_number_of_attributes_per_timed_event : typing___Optional[builtin___int] = None,
        max_number_of_links : typing___Optional[builtin___int] = None,
        max_number_of_attributes_per_link : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> TraceConfig: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> TraceConfig: ...
    def HasField(self, field_name: typing_extensions___Literal[u"constant_sampler",b"constant_sampler",u"probability_sampler",b"probability_sampler",u"rate_limiting_sampler",b"rate_limiting_sampler",u"sampler",b"sampler"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"constant_sampler",b"constant_sampler",u"max_number_of_attributes",b"max_number_of_attributes",u"max_number_of_attributes_per_link",b"max_number_of_attributes_per_link",u"max_number_of_attributes_per_timed_event",b"max_number_of_attributes_per_timed_event",u"max_number_of_links",b"max_number_of_links",u"max_number_of_timed_events",b"max_number_of_timed_events",u"probability_sampler",b"probability_sampler",u"rate_limiting_sampler",b"rate_limiting_sampler",u"sampler",b"sampler"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"sampler",b"sampler"]) -> typing_extensions___Literal["constant_sampler","probability_sampler","rate_limiting_sampler"]: ...
type___TraceConfig = TraceConfig

class ConstantSampler(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ConstantDecisionValue = typing___NewType('ConstantDecisionValue', builtin___int)
    type___ConstantDecisionValue = ConstantDecisionValue
    class ConstantDecision(object):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: builtin___int) -> builtin___str: ...
        @classmethod
        def Value(cls, name: builtin___str) -> ConstantSampler.ConstantDecisionValue: ...
        @classmethod
        def keys(cls) -> typing___List[builtin___str]: ...
        @classmethod
        def values(cls) -> typing___List[ConstantSampler.ConstantDecisionValue]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[builtin___str, ConstantSampler.ConstantDecisionValue]]: ...
        ALWAYS_OFF = typing___cast(ConstantSampler.ConstantDecisionValue, 0)
        ALWAYS_ON = typing___cast(ConstantSampler.ConstantDecisionValue, 1)
        ALWAYS_PARENT = typing___cast(ConstantSampler.ConstantDecisionValue, 2)
    ALWAYS_OFF = typing___cast(ConstantSampler.ConstantDecisionValue, 0)
    ALWAYS_ON = typing___cast(ConstantSampler.ConstantDecisionValue, 1)
    ALWAYS_PARENT = typing___cast(ConstantSampler.ConstantDecisionValue, 2)
    type___ConstantDecision = ConstantDecision

    decision: type___ConstantSampler.ConstantDecisionValue = ...

    def __init__(self,
        *,
        decision : typing___Optional[type___ConstantSampler.ConstantDecisionValue] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> ConstantSampler: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> ConstantSampler: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"decision",b"decision"]) -> None: ...
type___ConstantSampler = ConstantSampler

class ProbabilitySampler(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    samplingProbability: builtin___float = ...

    def __init__(self,
        *,
        samplingProbability : typing___Optional[builtin___float] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> ProbabilitySampler: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> ProbabilitySampler: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"samplingProbability",b"samplingProbability"]) -> None: ...
type___ProbabilitySampler = ProbabilitySampler

class RateLimitingSampler(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    qps: builtin___int = ...

    def __init__(self,
        *,
        qps : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> RateLimitingSampler: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> RateLimitingSampler: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"qps",b"qps"]) -> None: ...
type___RateLimitingSampler = RateLimitingSampler



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from opentelemetry.proto.common.v1.common_pb2 import (
    InstrumentationLibrary as opentelemetry___proto___common___v1___common_pb2___InstrumentationLibrary,
    StringKeyValue as opentelemetry___proto___common___v1___common_pb2___StringKeyValue,
)

from opentelemetry.proto.resource.v1.resource_pb2 import (
    Resource as opentelemetry___proto___resource___v1___resource_pb2___Resource,
)

from typing import (
    Iterable as typing___Iterable,
    List as typing___List,
    NewType as typing___NewType,
    Optional as typing___Optional,
    Text as typing___Text,
    Tuple as typing___Tuple,
    Union as typing___Union,
    cast as typing___cast,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
builtin___str = str
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

AggregationTemporalityValue = typing___NewType('AggregationTemporalityValue', builtin___int)
type___AggregationTemporalityValue = AggregationTemporalityValue
class AggregationTemporality(object):
    DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
    @classmethod
    def Name(cls, number: builtin___int) -> builtin___str: ...
    @classmethod
    def Value(cls, name: builtin___str) -> AggregationTemporalityValue: ...
    @classmethod
    def keys(cls) -> typing___List[builtin___str]: ...
    @classmethod
    def values(cls) -> typing___List[AggregationTemporalityValue]: ...
    @classmethod
    def items(cls) -> typing___List[typing___Tuple[builtin___str, AggregationTemporalityValue]]: ...
    AGGREGATION_TEMPORALITY_UNSPECIFIED = typing___cast(AggregationTemporalityValue, 0)
    AGGREGATION_TEMPORALITY_DELTA = typing___cast(AggregationTemporalityValue, 1)
    AGGREGATION_TEMPORALITY_CUMULATIVE = typing___cast(AggregationTemporalityValue, 2)
AGGREGATION_TEMPORALITY_UNSPECIFIED = typing___cast(AggregationTemporalityValue, 0)
AGGREGATION_TEMPORALITY_DELTA = typing___cast(AggregationTemporalityValue, 1)
AGGREGATION_TEMPORALITY_CUMULATIVE = typing___cast(AggregationTemporalityValue, 2)
type___AggregationTemporality = AggregationTemporality

class ResourceMetrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def resource(self) -> opentelemetry___proto___resource___v1___resource_pb2___Resource: ...

    @property
    def instrumentation_library_metrics(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___InstrumentationLibraryMetrics]: ...

    def __init__(self,
        *,
        resource : typing___Optional[opentelemetry___proto___resource___v1___resource_pb2___Resource] = None,
        instrumentation_library_metrics : typing___Optional[typing___Iterable[type___InstrumentationLibraryMetrics]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> ResourceMetrics: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> ResourceMetrics: ...
    def HasField(self, field_name: typing_extensions___Literal[u"resource",b"resource"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"instrumentation_library_metrics",b"instrumentation_library_metrics",u"resource",b"resource"]) -> None: ...
type___ResourceMetrics = ResourceMetrics

class InstrumentationLibraryMetrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def instrumentation_library(self) -> opentelemetry___proto___common___v1___common_pb2___InstrumentationLibrary: ...

    @property
    def metrics(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___Metric]: ...

    def __init__(self,
        *,
        instrumentation_library : typing___Optional[opentelemetry___proto___common___v1___common_pb2___InstrumentationLibrary] = None,
        metrics : typing___Optional[typing___Iterable[type___Metric]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> InstrumentationLibraryMetrics: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> InstrumentationLibraryMetrics: ...
    def HasField(self, field_name: typing_extensions___Literal[u"instrumentation_library",b"instrumentation_library"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"instrumentation_library",b"instrumentation_library",u"metrics",b"metrics"]) -> None: ...
type___InstrumentationLibraryMetrics = InstrumentationLibraryMetrics

class Metric(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    name: typing___Text = ...
    description: typing___Text = ...
    unit: typing___Text = ...

    @property
    def int_gauge(self) -> type___IntGauge: ...

    @property
    def double_gauge(self) -> type___DoubleGauge: ...

    @property
    def int_sum(self) -> type___IntSum: ...

    @property
    def double_sum(self) -> type___DoubleSum: ...

    @property
    def int_histogram(self) -> type___IntHistogram: ...

    @property
    def double_histogram(self) -> type___DoubleHistogram: ...

    def __init__(self,
        *,
        name : typing___Optional[typing___Text] = None,
        description : typing___Optional[typing___Text] = None,
        unit : typing___Optional[typing___Text] = None,
        int_gauge : typing___Optional[type___IntGauge] = None,
        double_gauge : typing___Optional[type___DoubleGauge] = None,
        int_sum : typing___Optional[type___IntSum] = None,
        double_sum : typing___Optional[type___DoubleSum] = None,
        int_histogram : typing___Optional[type___IntHistogram] = None,
        double_histogram : typing___Optional[type___DoubleHistogram] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> Metric: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Metric: ...
    def HasField(self, field_name: typing_extensions___Literal[u"data",b"data",u"double_gauge",b"double_gauge",u"double_histogram",b"double_histogram",u"double_sum",b"double_sum",u"int_gauge",b"int_gauge",u"int_histogram",b"int_histogram",u"int_sum",b"int_sum"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"data",b"data",u"description",b"description",u"double_gauge",b"double_gauge",u"double_histogram",b"double_histogram",u"double_sum",b"double_sum",u"int_gauge",b"int_gauge",u"int_histogram",b"int_histogram",u"int_sum",b"int_sum",u"name",b"name",u"unit",b"unit"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"data",b"data"]) -> typing_extensions___Literal["int_gauge","double_gauge","int_sum","double_sum","int_histogram","double_histogram"]: ...
type___Metric = Metric

class IntGauge(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def data_points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___IntDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing___Optional[typing___Iterable[type___IntDataPoint]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> IntGauge: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> IntGauge: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"data_points",b"data_points"]) -> None: ...
type___IntGauge = IntGauge

class DoubleGauge(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def data_points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___DoubleDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing___Optional[typing___Iterable[type___DoubleDataPoint]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> DoubleGauge: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> DoubleGauge: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"data_points",b"data_points"]) -> None: ...
type___DoubleGauge = DoubleGauge

class IntSum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    aggregation_temporality: type___AggregationTemporalityValue = ...
    is_monotonic: builtin___bool = ...

    @property
    def data_points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___IntDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing___Optional[typing___Iterable[type___IntDataPoint]] = None,
        aggregation_temporality : typing___Optional[type___AggregationTemporalityValue] = None,
        is_monotonic : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> IntSum: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> IntSum: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"aggregation_temporality",b"aggregation_temporality",u"data_points",b"data_points",u"is_monotonic",b"is_monotonic"]) -> None: ...
type___IntSum = IntSum

class DoubleSum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    aggregation_temporality: type___AggregationTemporalityValue = ...
    is_monotonic: builtin___bool = ...

    @property
    def data_points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___DoubleDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing___Optional[typing___Iterable[type___DoubleDataPoint]] = None,
        aggregation_temporality : typing___Optional[type___AggregationTemporalityValue] = None,
        is_monotonic : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> DoubleSum: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> DoubleSum: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"aggregation_temporality",b"aggregation_temporality",u"data_points",b"data_points",u"is_monotonic",b"is_monotonic"]) -> None: ...
type___DoubleSum = DoubleSum

class IntHistogram(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    aggregation_temporality: type___AggregationTemporalityValue = ...

    @property
    def data_points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___IntHistogramDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing___Optional[typing___Iterable[type___IntHistogramDataPoint]] = None,
        aggregation_temporality : typing___Optional[type___AggregationTemporalityValue] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> IntHistogram: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> IntHistogram: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"aggregation_temporality",b"aggregation_temporality",u"data_points",b"data_points"]) -> None: ...
type___IntHistogram = IntHistogram

class DoubleHistogram(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    aggregation_temporality: type___AggregationTemporalityValue = ...

    @property
    def data_points(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___DoubleHistogramDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing___Optional[typing___Iterable[type___DoubleHistogramDataPoint]] = None,
        aggregation_temporality : typing___Optional[type___AggregationTemporalityValue] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> DoubleHistogram: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> DoubleHistogram: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"aggregation_temporality",b"aggregation_temporality",u"data_points",b"data_points"]) -> None: ...
type___DoubleHistogram = DoubleHistogram

class IntDataPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    start_time_unix_nano: builtin___int = ...
    time_unix_nano: builtin___int = ...
    value: builtin___int = ...

    @property
    def labels(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]: ...

    @property
    def exemplars(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___IntExemplar]: ...

    def __init__(self,
        *,
        labels : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]] = None,
        start_time_unix_nano : typing___Optional[builtin___int] = None,
        time_unix_nano : typing___Optional[builtin___int] = None,
        value : typing___Optional[builtin___int] = None,
        exemplars : typing___Optional[typing___Iterable[type___IntExemplar]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> IntDataPoint: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> IntDataPoint: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"exemplars",b"exemplars",u"labels",b"labels",u"start_time_unix_nano",b"start_time_unix_nano",u"time_unix_nano",b"time_unix_nano",u"value",b"value"]) -> None: ...
type___IntDataPoint = IntDataPoint

class DoubleDataPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    start_time_unix_nano: builtin___int = ...
    time_unix_nano: builtin___int = ...
    value: builtin___float = ...

    @property
    def labels(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]: ...

    @property
    def exemplars(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___DoubleExemplar]: ...

    def __init__(self,
        *,
        labels : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]] = None,
        start_time_unix_nano : typing___Optional[builtin___int] = None,
        time_unix_nano : typing___Optional[builtin___int] = None,
        value : typing___Optional[builtin___float] = None,
        exemplars : typing___Optional[typing___Iterable[type___DoubleExemplar]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> DoubleDataPoint: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> DoubleDataPoint: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"exemplars",b"exemplars",u"labels",b"labels",u"start_time_unix_nano",b"start_time_unix_nano",u"time_unix_nano",b"time_unix_nano",u"value",b"value"]) -> None: ...
type___DoubleDataPoint = DoubleDataPoint

class IntHistogramDataPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    start_time_unix_nano: builtin___int = ...
    time_unix_nano: builtin___int = ...
    count: builtin___int = ...
    sum: builtin___int = ...
    bucket_counts: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...
    explicit_bounds: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...

    @property
    def labels(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]: ...

    @property
    def exemplars(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___IntExemplar]: ...

    def __init__(self,
        *,
        labels : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]] = None,
        start_time_unix_nano : typing___Optional[builtin___int] = None,
        time_unix_nano : typing___Optional[builtin___int] = None,
        count : typing___Optional[builtin___int] = None,
        sum : typing___Optional[builtin___int] = None,
        bucket_counts : typing___Optional[typing___Iterable[builtin___int]] = None,
        explicit_bounds : typing___Optional[typing___Iterable[builtin___float]] = None,
        exemplars : typing___Optional[typing___Iterable[type___IntExemplar]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> IntHistogramDataPoint: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> IntHistogramDataPoint: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"bucket_counts",b"bucket_counts",u"count",b"count",u"exemplars",b"exemplars",u"explicit_bounds",b"explicit_bounds",u"labels",b"labels",u"start_time_unix_nano",b"start_time_unix_nano",u"sum",b"sum",u"time_unix_nano",b"time_unix_nano"]) -> None: ...
type___IntHistogramDataPoint = IntHistogramDataPoint

class DoubleHistogramDataPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    start_time_unix_nano: builtin___int = ...
    time_unix_nano: builtin___int = ...
    count: builtin___int = ...
    sum: builtin___float = ...
    bucket_counts: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...
    explicit_bounds: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...

    @property
    def labels(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]: ...

    @property
    def exemplars(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___DoubleExemplar]: ...

    def __init__(self,
        *,
        labels : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]] = None,
        start_time_unix_nano : typing___Optional[builtin___int] = None,
        time_unix_nano : typing___Optional[builtin___int] = None,
        count : typing___Optional[builtin___int] = None,
        sum : typing___Optional[builtin___float] = None,
        bucket_counts : typing___Optional[typing___Iterable[builtin___int]] = None,
        explicit_bounds : typing___Optional[typing___Iterable[builtin___float]] = None,
        exemplars : typing___Optional[typing___Iterable[type___DoubleExemplar]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> DoubleHistogramDataPoint: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> DoubleHistogramDataPoint: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"bucket_counts",b"bucket_counts",u"count",b"count",u"exemplars",b"exemplars",u"explicit_bounds",b"explicit_bounds",u"labels",b"labels",u"start_time_unix_nano",b"start_time_unix_nano",u"sum",b"sum",u"time_unix_nano",b"time_unix_nano"]) -> None: ...
type___DoubleHistogramDataPoint = DoubleHistogramDataPoint

class IntExemplar(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    time_unix_nano: builtin___int = ...
    value: builtin___int = ...
    span_id: builtin___bytes = ...
    trace_id: builtin___bytes = ...

    @property
    def filtered_labels(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]: ...

    def __init__(self,
        *,
        filtered_labels : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]] = None,
        time_unix_nano : typing___Optional[builtin___int] = None,
        value : typing___Optional[builtin___int] = None,
        span_id : typing___Optional[builtin___bytes] = None,
        trace_id : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> IntExemplar: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> IntExemplar: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"filtered_labels",b"filtered_labels",u"span_id",b"span_id",u"time_unix_nano",b"time_unix_nano",u"trace_id",b"trace_id",u"value",b"value"]) -> None: ...
type___IntExemplar = IntExemplar

class DoubleExemplar(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    time_unix_nano: builtin___int = ...
    value: builtin___float = ...
    span_id: builtin___bytes = ...
    trace_id: builtin___bytes = ...

    @property
    def filtered_labels(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]: ...

    def __init__(self,
        *,
        filtered_labels : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___StringKeyValue]] = None,
        time_unix_nano : typing___Optional[builtin___int] = None,
        value : typing___Optional[builtin___float] = None,
        span_id : typing___Optional[builtin___bytes] = None,
        trace_id : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> DoubleExemplar: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> DoubleExemplar: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"filtered_labels",b"filtered_labels",u"span_id",b"span_id",u"time_unix_nano",b"time_unix_nano",u"trace_id",b"trace_id",u"value",b"value"]) -> None: ...
type___DoubleExemplar = DoubleExemplar



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from opentelemetry.proto.common.v1.common_pb2 import (
    InstrumentationLibrary as opentelemetry___proto___common___v1___common_pb2___InstrumentationLibrary,
    KeyValue as opentelemetry___proto___common___v1___common_pb2___KeyValue,
)

from opentelemetry.proto.resource.v1.resource_pb2 import (
    Resource as opentelemetry___proto___resource___v1___resource_pb2___Resource,
)

from typing import (
    Iterable as typing___Iterable,
    List as typing___List,
    NewType as typing___NewType,
    Optional as typing___Optional,
    Text as typing___Text,
    Tuple as typing___Tuple,
    Union as typing___Union,
    cast as typing___cast,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
builtin___str = str
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ResourceSpans(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def resource(self) -> opentelemetry___proto___resource___v1___resource_pb2___Resource: ...

    @property
    def instrumentation_library_spans(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___InstrumentationLibrarySpans]: ...

    def __init__(self,
        *,
        resource : typing___Optional[opentelemetry___proto___resource___v1___resource_pb2___Resource] = None,
        instrumentation_library_spans : typing___Optional[typing___Iterable[type___InstrumentationLibrarySpans]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> ResourceSpans: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> ResourceSpans: ...
    def HasField(self, field_name: typing_extensions___Literal[u"resource",b"resource"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"instrumentation_library_spans",b"instrumentation_library_spans",u"resource",b"resource"]) -> None: ...
type___ResourceSpans = ResourceSpans

class InstrumentationLibrarySpans(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def instrumentation_library(self) -> opentelemetry___proto___common___v1___common_pb2___InstrumentationLibrary: ...

    @property
    def spans(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___Span]: ...

    def __init__(self,
        *,
        instrumentation_library : typing___Optional[opentelemetry___proto___common___v1___common_pb2___InstrumentationLibrary] = None,
        spans : typing___Optional[typing___Iterable[type___Span]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> InstrumentationLibrarySpans: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> InstrumentationLibrarySpans: ...
    def HasField(self, field_name: typing_extensions___Literal[u"instrumentation_library",b"instrumentation_library"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"instrumentation_library",b"instrumentation_library",u"spans",b"spans"]) -> None: ...
type___InstrumentationLibrarySpans = InstrumentationLibrarySpans

class Span(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    SpanKindValue = typing___NewType('SpanKindValue', builtin___int)
    type___SpanKindValue = SpanKindValue
    class SpanKind(object):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: builtin___int) -> builtin___str: ...
        @classmethod
        def Value(cls, name: builtin___str) -> Span.SpanKindValue: ...
        @classmethod
        def keys(cls) -> typing___List[builtin___str]: ...
        @classmethod
        def values(cls) -> typing___List[Span.SpanKindValue]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[builtin___str, Span.SpanKindValue]]: ...
        SPAN_KIND_UNSPECIFIED = typing___cast(Span.SpanKindValue, 0)
        SPAN_KIND_INTERNAL = typing___cast(Span.SpanKindValue, 1)
        SPAN_KIND_SERVER = typing___cast(Span.SpanKindValue, 2)
        SPAN_KIND_CLIENT = typing___cast(Span.SpanKindValue, 3)
        SPAN_KIND_PRODUCER = typing___cast(Span.SpanKindValue, 4)
        SPAN_KIND_CONSUMER = typing___cast(Span.SpanKindValue, 5)
    SPAN_KIND_UNSPECIFIED = typing___cast(Span.SpanKindValue, 0)
    SPAN_KIND_INTERNAL = typing___cast(Span.SpanKindValue, 1)
    SPAN_KIND_SERVER = typing___cast(Span.SpanKindValue, 2)
    SPAN_KIND_CLIENT = typing___cast(Span.SpanKindValue, 3)
    SPAN_KIND_PRODUCER = typing___cast(Span.SpanKindValue, 4)
    SPAN_KIND_CONSUMER = typing___cast(Span.SpanKindValue, 5)
    type___SpanKind = SpanKind

    class Event(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        time_unix_nano: builtin___int = ...
        name: typing___Text = ...
        dropped_attributes_count: builtin___int = ...

        @property
        def attributes(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___KeyValue]: ...

        def __init__(self,
            *,
            time_unix_nano : typing___Optional[builtin___int] = None,
            name : typing___Optional[typing___Text] = None,
            attributes : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___KeyValue]] = None,
            dropped_attributes_count : typing___Optional[builtin___int] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Span.Event: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Span.Event: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"attributes",b"attributes",u"dropped_attributes_count",b"dropped_attributes_count",u"name",b"name",u"time_unix_nano",b"time_unix_nano"]) -> None: ...
    type___Event = Event

    class Link(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        trace_id: builtin___bytes = ...
        span_id: builtin___bytes = ...
        trace_state: typing___Text = ...
        dropped_attributes_count: builtin___int = ...

        @property
        def attributes(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___KeyValue]: ...

        def __init__(self,
            *,
            trace_id : typing___Optional[builtin___bytes] = None,
            span_id : typing___Optional[builtin___bytes] = None,
            trace_state : typing___Optional[typing___Text] = None,
            attributes : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___KeyValue]] = None,
            dropped_attributes_count : typing___Optional[builtin___int] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> Span.Link: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Span.Link: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"attributes",b"attributes",u"dropped_attributes_count",b"dropped_attributes_count",u"span_id",b"span_id",u"trace_id",b"trace_id",u"trace_state",b"trace_state"]) -> None: ...
    type___Link = Link

    trace_id: builtin___bytes = ...
    span_id: builtin___bytes = ...
    trace_state: typing___Text = ...
    parent_span_id: builtin___bytes = ...
    name: typing___Text = ...
    kind: type___Span.SpanKindValue = ...
    start_time_unix_nano: builtin___int = ...
    end_time_unix_nano: builtin___int = ...
    dropped_attributes_count: builtin___int = ...
    dropped_events_count: builtin___int = ...
    dropped_links_count: builtin___int = ...

    @property
    def attributes(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___common___v1___common_pb2___KeyValue]: ...

    @property
    def events(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___Span.Event]: ...

    @property
    def links(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___Span.Link]: ...

    @property
    def status(self) -> type___Status: ...

    def __init__(self,
        *,
        trace_id : typing___Optional[builtin___bytes] = None,
        span_id : typing___Optional[builtin___bytes] = None,
        trace_state : typing___Optional[typing___Text] = None,
        parent_span_id : typing___Optional[builtin___bytes] = None,
        name : typing___Optional[typing___Text] = None,
        kind : typing___Optional[type___Span.SpanKindValue] = None,
        start_time_unix_nano : typing___Optional[builtin___int] = None,
        end_time_unix_nano : typing___Optional[builtin___int] = None,
        attributes : typing___Optional[typing___Iterable[opentelemetry___proto___common___v1___common_pb2___KeyValue]] = None,
        dropped_attributes_count : typing___Optional[builtin___int] = None,
        events : typing___Optional[typing___Iterable[type___Span.Event]] = None,
        dropped_events_count : typing___Optional[builtin___int] = None,
        links : typing___Optional[typing___Iterable[type___Span.Link]] = None,
        dropped_links_count : typing___Optional[builtin___int] = None,
        status : typing___Optional[type___Status] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> Span: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Span: ...
    def HasField(self, field_name: typing_extensions___Literal[u"status",b"status"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"attributes",b"attributes",u"dropped_attributes_count",b"dropped_attributes_count",u"dropped_events_count",b"dropped_events_count",u"dropped_links_count",b"dropped_links_count",u"end_time_unix_nano",b"end_time_unix_nano",u"events",b"events",u"kind",b"kind",u"links",b"links",u"name",b"name",u"parent_span_id",b"parent_span_id",u"span_id",b"span_id",u"start_time_unix_nano",b"start_time_unix_nano",u"status",b"status",u"trace_id",b"trace_id",u"trace_state",b"trace_state"]) -> None: ...
type___Span = Span

class Status(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    StatusCodeValue = typing___NewType('StatusCodeValue', builtin___int)
    type___StatusCodeValue = StatusCodeValue
    class StatusCode(object):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: builtin___int) -> builtin___str: ...
        @classmethod
        def Value(cls, name: builtin___str) -> Status.StatusCodeValue: ...
        @classmethod
        def keys(cls) -> typing___List[builtin___str]: ...
        @classmethod
        def values(cls) -> typing___List[Status.StatusCodeValue]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[builtin___str, Status.StatusCodeValue]]: ...
        STATUS_CODE_OK = typing___cast(Status.StatusCodeValue, 0)
        STATUS_CODE_CANCELLED = typing___cast(Status.StatusCodeValue, 1)
        STATUS_CODE_UNKNOWN_ERROR = typing___cast(Status.StatusCodeValue, 2)
        STATUS_CODE_INVALID_ARGUMENT = typing___cast(Status.StatusCodeValue, 3)
        STATUS_CODE_DEADLINE_EXCEEDED = typing___cast(Status.StatusCodeValue, 4)
        STATUS_CODE_NOT_FOUND = typing___cast(Status.StatusCodeValue, 5)
        STATUS_CODE_ALREADY_EXISTS = typing___cast(Status.StatusCodeValue, 6)
        STATUS_CODE_PERMISSION_DENIED = typing___cast(Status.StatusCodeValue, 7)
        STATUS_CODE_RESOURCE_EXHAUSTED = typing___cast(Status.StatusCodeValue, 8)
        STATUS_CODE_FAILED_PRECONDITION = typing___cast(Status.StatusCodeValue, 9)
        STATUS_CODE_ABORTED = typing___cast(Status.StatusCodeValue, 10)
        STATUS_CODE_OUT_OF_RANGE = typing___cast(Status.StatusCodeValue, 11)
        STATUS_CODE_UNIMPLEMENTED = typing___cast(Status.StatusCodeValue, 12)
        STATUS_CODE_INTERNAL_ERROR = typing___cast(Status.StatusCodeValue, 13)
        STATUS_CODE_UNAVAILABLE = typing___cast(Status.StatusCodeValue, 14)
        STATUS_CODE_DATA_LOSS = typing___cast(Status.StatusCodeValue, 15)
        STATUS_CODE_UNAUTHENTICATED = typing___cast(Status.StatusCodeValue, 16)
    STATUS_CODE_OK = typing___cast(Status.StatusCodeValue, 0)
    STATUS_CODE_CANCELLED = typing___cast(Status.StatusCodeValue, 1)
    STATUS_CODE_UNKNOWN_ERROR = typing___cast(Status.StatusCodeValue, 2)
    STATUS_CODE_INVALID_ARGUMENT = typing___cast(Status.StatusCodeValue, 3)
    STATUS_CODE_DEADLINE_EXCEEDED = typing___cast(Status.StatusCodeValue, 4)
    STATUS_CODE_NOT_FOUND = typing___cast(Status.StatusCodeValue, 5)
    STATUS_CODE_ALREADY_EXISTS = typing___cast(Status.StatusCodeValue, 6)
    STATUS_CODE_PERMISSION_DENIED = typing___cast(Status.StatusCodeValue, 7)
    STATUS_CODE_RESOURCE_EXHAUSTED = typing___cast(Status.StatusCodeValue, 8)
    STATUS_CODE_FAILED_PRECONDITION = typing___cast(Status.StatusCodeValue, 9)
    STATUS_CODE_ABORTED = typing___cast(Status.StatusCodeValue, 10)
    STATUS_CODE_OUT_OF_RANGE = typing___cast(Status.StatusCodeValue, 11)
    STATUS_CODE_UNIMPLEMENTED = typing___cast(Status.StatusCodeValue, 12)
    STATUS_CODE_INTERNAL_ERROR = typing___cast(Status.StatusCodeValue, 13)
    STATUS_CODE_UNAVAILABLE = typing___cast(Status.StatusCodeValue, 14)
    STATUS_CODE_DATA_LOSS = typing___cast(Status.StatusCodeValue, 15)
    STATUS_CODE_UNAUTHENTICATED = typing___cast(Status.StatusCodeValue, 16)
    type___StatusCode = StatusCode

    code: type___Status.StatusCodeValue = ...
    message: typing___Text = ...

    def __init__(self,
        *,
        code : typing___Optional[type___Status.StatusCodeValue] = None,
        message : typing___Optional[typing___Text] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> Status: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Status: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"code",b"code",u"message",b"message"]) -> None: ...
type___Status = Status



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from opentelemetry.proto.logs.v1.logs_pb2 import (
    ResourceLogs as opentelemetry___proto___logs___v1___logs_pb2___ResourceLogs,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ExportLogsServiceRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def resource_logs(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[opentelemetry___proto___logs___v1___logs_pb2___ResourceLogs]: ...

    def __init__(self,
        *,
        resource_logs : typing___Optional[typing___Iterable[opentelemetry___proto___logs___v1___logs_pb2___ResourceLogs]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> ExportLogsServiceRequest: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> ExportLogsServiceRequest: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"resource_logs",b"resource_logs"]) -> None: ...
type___ExportLogsServiceRequest = ExportLogsServiceRequest

class ExportLogsServiceResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    def __init__(self,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> ExportLogsServiceResponse: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> ExportLogsServiceResponse: ...
type___ExportLogsServiceResponse = ExportLogsServiceResponse
